Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(202)

Unified Diff: dart/lib/compiler/implementation/enqueue.dart

Issue 10661029: Ensure interfaces are loaded. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: dart/lib/compiler/implementation/enqueue.dart
diff --git a/dart/lib/compiler/implementation/enqueue.dart b/dart/lib/compiler/implementation/enqueue.dart
index b2ff2a0985dfcb9c952f669c548a925e7eeb745a..58dc86956178469570a167358ad3f74054fe691b 100644
--- a/dart/lib/compiler/implementation/enqueue.dart
+++ b/dart/lib/compiler/implementation/enqueue.dart
@@ -208,9 +208,9 @@ class Enqueuer {
while (cls !== null) {
if (seenClasses.contains(cls)) return;
seenClasses.add(cls);
- // TODO(ahe): Don't call resolveType, instead, call this method
- // when resolveType is called.
- compiler.resolveClass(cls);
+ // TODO(ahe): Don't call ensureResolved, instead, call this method
+ // from the resolver.
+ cls.ensureResolved(compiler);
cls.members.forEach(processInstantiatedClassMember);
cls = cls.superclass;
}

Powered by Google App Engine
This is Rietveld 408576698